@@ -3,8 +3,8 @@
 
 #include "imdatatypes.h"
 
-i_img   * i_readheif(io_glue *ig, int page);
-i_img  ** i_readheif_multi(io_glue *ig, int *count);
+i_img   * i_readheif(io_glue *ig, int page, int max_threads);
+i_img  ** i_readheif_multi(io_glue *ig, int *count, int max_threads);
 undef_int i_writeheif(i_img *im, io_glue *ig);
 undef_int i_writeheif_multi(io_glue *ig, i_img **imgs, int count);
 char const * i_heif_libversion(void);
